Struct CausalLMOutput

pub struct CausalLMOutput { /* private fields */ }
Causal language model output.

Implementations

Source

impl CausalLMOutput

pub fn new(decoder_output: DecoderOutput, logits: Tensor) -> Self

Create a causal language model output.

pub fn decoder_output(&self) -> &DecoderOutput

Get the output of the decoder used by the causal language model.

pub fn logits(&self) -> &Tensor

Get the logits of the next predicted token.

The logits are the unnormalized probabilities. Applying softmax to the logits will give the probability distribution of the next token over the vocabulary.