pub struct TransformerEmbeddingsConfig { /* private fields */ }Expand description
Configuration for transformer embedding layer.
Implementations
Sourceimpl TransformerEmbeddingsConfig
impl TransformerEmbeddingsConfig
Sourcepub fn embedding_dropout(self, embedding_dropout: Box<dyn BuildModule>) -> Self
pub fn embedding_dropout(self, embedding_dropout: Box<dyn BuildModule>) -> Self
Dropout to apply to the embeddings.
Default: Identity.
Sourcepub fn embedding_layer_norm(
self,
embedding_layer_norm: Box<dyn BuildModule>,
) -> Self
pub fn embedding_layer_norm( self, embedding_layer_norm: Box<dyn BuildModule>, ) -> Self
Layer normalization to apply to the embeddings.
Default: Identity.
Sourcepub fn embedding_width(self, embedding_width: usize) -> Self
pub fn embedding_width(self, embedding_width: usize) -> Self
Width of the embeddings.
Default: 768.
Width of the transformer.
The embedding layer will use a projection if the hidden width is not equal to the embedding width.
Default: 768.
Sourcepub fn n_positions(self, n_positions: Option<usize>) -> Self
pub fn n_positions(self, n_positions: Option<usize>) -> Self
Number of position embeddings.
Default: None.
Sourcepub fn n_pieces(self, n_pieces: usize) -> Self
pub fn n_pieces(self, n_pieces: usize) -> Self
Vocabulary size (number of embeddings).
Default: 30000.
Sourcepub fn n_types(self, n_types: Option<usize>) -> Self
pub fn n_types(self, n_types: Option<usize>) -> Self
Token type vocabulary size (number of token type embeddings).
Default: None.
Sourcepub fn projection_dropout(
self,
projection_dropout: Box<dyn BuildModule>,
) -> Self
pub fn projection_dropout( self, projection_dropout: Box<dyn BuildModule>, ) -> Self
Dropout to apply after embedding projection.
Default: Identity.
Sourcepub fn projection_layer_norm(
self,
projection_layer_norm: Box<dyn BuildModule>,
) -> Self
pub fn projection_layer_norm( self, projection_layer_norm: Box<dyn BuildModule>, ) -> Self
Layer normalization to apply to the projection layer.
Default: Identity.