pub struct AlbertEncoderConfig { /* private fields */ }Expand description
ALBERT encoder configuration.
Configuration for AlbertEncoder. ALBERT differs from an encoder like BERT in two ways:
- The embedding size can be different from the hidden size. A projection matrix is used when the sizes differ.
- A group of layers can share parameters. For instance, if the number of
layers (
n_hidden_layers) is 12 and the number of groups (n_hidden_groups) is 4, then layers 0..3, 3..6, 6..9, and 9..12 will share parameters.
Implementations
Sourceimpl AlbertEncoderConfig
impl AlbertEncoderConfig
Sourcepub fn embeddings(self, embeddings: Box<dyn BuildEmbeddings>) -> Self
pub fn embeddings(self, embeddings: Box<dyn BuildEmbeddings>) -> Self
Encoder embeddings.
Default: TransformerEmbeddingsConfig::default()
Sourcepub fn layer_group(self, layer_group: Box<dyn BuildEncoderLayer>) -> Self
pub fn layer_group(self, layer_group: Box<dyn BuildEncoderLayer>) -> Self
Number of layers within a group.
Default: AlbertLayerGroupConfig::default()
Number of hidden groups.
Default: 1
Number of hidden layers.
Default: 12